@@ -4,7 +4,7 @@
  * Universite Pierre et Marie Curie
  * 
  * Home page          : http://www-asim.lip6.fr/alliance/
- * E-mail support     : mailto:alliance-support@asim.lip6.fr
+ * E-mail             : mailto:alliance-users@asim.lip6.fr
  * 
  * This progam is  free software; you can redistribute it  and/or modify it
  * under the  terms of the GNU  General Public License as  published by the
@@ -110,6 +110,20 @@ extern void genSC_CHANNEL();
 extern void genSC_CON_CHANNEL();
 extern void genLOGEN(char *, int, ...);;
 extern void genSETLOGEN(char *, char *, ...);
+
+/********************************* Analogical world ************************************/
+
+extern void genLOCAP(char type,double capa,char *tcon,char *bcon,char *name)    ;
+extern void genLORES(char type,double resi,char *rcon1,char *rcon2,char *name)  ;
+extern void genLOSELF(char type,double self,char *scon1,char *scon2,char *name) ;
+
+extern void genSET_LOCAP(char *figname,char *capname,double newcap)    ;
+extern void genSET_LORES(char *figname,char *resname,double newres)    ;
+extern void genSET_LOSELF(char *figname,char *selfname,double newself) ;
+
+/***************************************************************************************/
+
+
 /*******************************************************************************
 * name forming functions, for both views                                       *
 *******************************************************************************/
@@ -261,6 +275,19 @@ extern char *genNAME(char *, ...);
 #define GENLIB_ELM(signame,number)               genELM(signame,number)
 #define GENLIB_NAME                              genNAME
 
+
+/********************************* Analogical world ************************************/
+
+#define GENLIB_LOCAP(type,capa,tcon,bcon,name)      genLOCAP(type,capa,tcon,bcon,name)
+#define GENLIB_LORES(type,resi,rcon1,rcon2,name)    genLORES(type,resi,rcon1,rcon2,name)
+#define GENLIB_LOSELF(type,self,scon1,scon2,name)   genLOSELF(type,self,scon1,scon2,name)
+
+#define GENLIB_SET_LOCAP(figname,capname,newcap)    genSET_LOCAP(figname,capname,newcap)
+#define GENLIB_SET_LORES(figname,resname,newres)    genSET_LORES(figname,resname,newres)
+#define GENLIB_SET_LOSELF(figname,selfname,newself) genSET_LOSELF(figname,selfname,newself)
+
+/***************************************************************************************/
+
 #endif
 
 /*
