@@ -4,7 +4,7 @@
  * Universite Pierre et Marie Curie
  * 
  * Home page          : http://www-asim.lip6.fr/alliance/
- * E-mail support     : mailto:alliance-support@asim.lip6.fr
+ * E-mail             : mailto:alliance-users@asim.lip6.fr
  * 
  * This progam is  free software; you can redistribute it  and/or modify it
  * under the  terms of the GNU  General Public License as  published by the
@@ -41,6 +41,9 @@
 /*                                                                          */
 /****************************************************************************/
 /* $Log: lvx.c,v $
+/* Revision 1.3  2002/09/30 16:20:46  czo
+/* support/users
+/*
 /* Revision 1.2  2002/03/22 09:45:47  xtof
 /* ALLIANCE_VERSION
 /*
@@ -85,7 +88,7 @@
  *
  */
 
-static char rcsid[] = "$Id: lvx.c,v 1.2 2002/03/22 09:45:47 xtof Exp $" ;
+static char rcsid[] = "$Id: lvx.c,v 1.3 2002/09/30 16:20:46 czo Exp $" ;
 
 #include <stdio.h>
 #include <string.h>
