@@ -4,7 +4,7 @@
  * Universite Pierre et Marie Curie
  * 
  * Home page          : http://www-asim.lip6.fr/alliance/
- * E-mail support     : mailto:alliance-support@asim.lip6.fr
+ * E-mail             : mailto:alliance-users@asim.lip6.fr
  * 
  * This library is free software; you  can redistribute it and/or modify it
  * under the terms  of the GNU Library General Public  License as published
@@ -28,7 +28,7 @@
  * Modified by Czo <Olivier.Sirol@lip6.fr> 1997,98
  */
 
-#ident "$Id: mbk_util.c,v 1.1.1.1 2002/03/08 13:51:05 fred Exp $"
+#ident "$Id: mbk_util.c,v 1.3 2003/04/03 14:46:30 xtof Exp $"
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -72,6 +72,7 @@ long SCALE_X = 100;                            /* distance scale definition   */
 char PARSER_INFO[100] = "nothing yet";         /* version number, and so on   */
 char *VDD = NULL;                              /* user name for power high    */
 char *VSS = NULL;                              /* user name for power ground  */
+char *CK = NULL;                               /* user name for clock         */
 char *IN_FILTER = NULL ;
 char *OUT_FILTER = NULL ;
 char *FILTER_SFX = NULL ;
@@ -319,6 +320,12 @@ static char MBK_RAND_SEED[] = { 0x62,
       VSS = str;
    else /* default value for power high */
       VSS = "vss";
+   
+   str = mbkgetenv("MBK_CK");
+   if (str != NULL)
+      CK = str;
+   else /* default value for clock */
+      CK = "ck";
 
    str = mbkgetenv( "MBK_IN_FILTER" );
    if( str )
@@ -1423,7 +1430,7 @@ static char *msg[6] = {
    "Copyright (c) %s-%d,\"ASIM/LIP6/UPMC",
    "Author(s):\"%s",
    "Contributor(s):\"%s",
-   "E-mail support:\"alliance-support@asim.lip6.fr"
+   "E-mail        :\"alliance-users@asim.lip6.fr"
 };
 int msgl[6];
 char *str;
