@@ -4,7 +4,7 @@
  * Universite Pierre et Marie Curie
  * 
  * Home page          : http://www-asim.lip6.fr/alliance/
- * E-mail support     : mailto:alliance-support@asim.lip6.fr
+ * E-mail             : mailto:alliance-users@asim.lip6.fr
  * 
  * This library is free software; you  can redistribute it and/or modify it
  * under the terms  of the GNU Library General Public  License as published
@@ -38,7 +38,7 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
-#include <varargs.h>
+#include <stdarg.h>
 #include <time.h>
 #include <ctype.h>
 #include <mut.h>
@@ -51,6 +51,16 @@
 #include "spi_msg.h"
 #include "spi_global.h"
 
+
+
+void sort_locap(lofig_list *ptfig,FILE *df)  ;
+void sort_lores(lofig_list *ptfig,FILE *df)  ;
+void sort_loself(lofig_list *ptfig,FILE *df) ;
+
+
+
+
+
 static char    *TNMOS,
                *TPMOS;
 char           *SPI_NETNAME;
@@ -643,30 +653,31 @@ char            *vdd;
     }
 
     tooutput( df, "%s ", spitransmodel( scantrs->TYPE ) );
+#define SCALED(x,y) (double)((double)(x)/(double)(y))
 
     if(scantrs->LENGTH!=0)
-      tooutput( df, "L=%gU ", (float)scantrs->LENGTH/SCALE_X );
+      tooutput( df, "L=%gU ", SCALED(scantrs->LENGTH, SCALE_X));
 
     if(scantrs->WIDTH!=0)
-      tooutput( df, "W=%gU ", (float)scantrs->WIDTH/SCALE_X );
+      tooutput( df, "W=%gU ", SCALED(scantrs->WIDTH, SCALE_X));
     
     if( scantrs->XS != 0 )
       tooutput( df,
                 "AS=%gP ",
-                (float) scantrs->XS * scantrs->WIDTH / ( SCALE_X * SCALE_X )
+                SCALED(scantrs->XS * scantrs->WIDTH,  SCALE_X * SCALE_X)
               );
 
     if( scantrs->XD != 0 )
       tooutput( df,
                 "AD=%gP ",
-                (float) scantrs->XD * scantrs->WIDTH / ( SCALE_X * SCALE_X )
+                SCALED(scantrs->XD * scantrs->WIDTH,  SCALE_X * SCALE_X)
               );
 
     if( scantrs->PS != 0 )
-      tooutput( df, "PS=%gU ", (float)scantrs->PS/SCALE_X );
+      tooutput( df, "PS=%gU ", SCALED(scantrs->PS, SCALE_X));
  
     if( scantrs->PD != 0 )
-      tooutput( df, "PD=%gU ", (float)scantrs->PD/SCALE_X );
+      tooutput( df, "PD=%gU ", SCALED(scantrs->PD, SCALE_X));
 
     tooutput( df, "\n" );
   }
@@ -712,6 +723,11 @@ FILE		*df;
 
   sortinstance( ptfig, df );
   sorttransistormos( ptfig, df, vss, vdd);
+
+  sort_locap(ptfig,df)  ;
+  sort_lores(ptfig,df)  ;
+  sort_loself(ptfig,df) ;
+
   sortrcn( ptfig, df, vss );
 
   tooutput( df, ".ends %s\n\n", ptfig->NAME );
@@ -890,16 +906,13 @@ lofig_list	*ptfig;
   }
 }
 
-void            tooutput( va_alist )
-va_dcl
+void            tooutput( FILE *fd, ... )
 {
   va_list       index;
-  FILE          *fd;
   char          *fmt;
 
-  va_start( index );
+  va_start( index, fd );
   
-  fd  = va_arg( index, FILE* );
   fmt = va_arg( index, char* );
 
   if( vfprintf( fd, fmt, index ) < 0 )
@@ -909,6 +922,8 @@ va_dcl
     perror( "System say " );
     EXIT( 1 );
   }
+
+  va_end( index );
 }
 
 void spi_vect( s )
@@ -942,3 +957,204 @@ char *s;
     }
   }
 }
+
+
+/****************************************************************************************************/
+/************************************** locap, lores and loself *************************************/
+/****************************************************************************************************/
+
+void sort_locap(lofig_list *ptfig,FILE *df)
+{
+  locap_list	*scancap   = NULL ;
+  int		nb         = 0    ;
+  ht            *capname   = NULL ;
+  char          name[1024]        ;
+  char          *ptr       = NULL ;
+
+  for(scancap = ptfig -> LOCAP,nb = 1 ; scancap != NULL; scancap = scancap -> NEXT,nb++) ;
+
+  capname = addht(nb) ;
+
+  nb = 0 ;
+
+  for(scancap = ptfig -> LOCAP ; scancap != NULL ; scancap = scancap -> NEXT)
+    {
+      if(scancap -> NAME != NULL)
+	{
+	  if(gethtitem(capname,scancap -> NAME) != EMPTYHT)
+	    {
+	      do
+		{
+		  nb++ ;
+		  sprintf(name,"%s_%d",scancap -> NAME,nb) ;
+		  ptr = namealloc(name) ;
+		}
+
+	      while(gethtitem(capname,ptr) != EMPTYHT) ;
+
+	      addhtitem(capname,ptr,1) ;
+	      tooutput(df,"C%s ",name) ;    
+	    }
+	  else
+	    {
+	      tooutput(df,"C%s ",scancap -> NAME) ;
+	      addhtitem(capname,scancap -> NAME,1) ;
+	    }
+	}
+      else
+	{
+	  do
+	    {
+	      nb++ ;
+	      sprintf(name,"%d",nb) ;
+	      ptr = namealloc(name) ;
+	    }
+
+	  while(gethtitem(capname,ptr) != EMPTYHT) ;
+
+	  tooutput(df,"C%s ",name) ;
+	  addhtitem(capname,ptr,1) ;
+	}
+
+      sortconnecteur(df,scancap -> TCON,1) ;
+      sortconnecteur(df,scancap -> BCON,1) ;
+
+      tooutput(df,"%g ",(float)scancap -> CAPA) ;
+
+      tooutput(df,"\n") ;
+    }
+
+  delht(capname) ;
+}
+
+/****************************************************************************************************/
+
+void sort_lores(lofig_list *ptfig,FILE *df)
+{
+  lores_list	*scanres   = NULL ;
+  int		nb         = 0    ;
+  ht            *resname   = NULL ;
+  char          name[1024]        ;
+  char          *ptr       = NULL ;
+
+  for(scanres = ptfig -> LORES,nb = 1 ; scanres != NULL; scanres = scanres -> NEXT,nb++) ;
+
+  resname = addht(nb) ;
+
+  nb = 0 ;
+
+  for(scanres = ptfig -> LORES ; scanres != NULL ; scanres = scanres -> NEXT)
+    {
+      if(scanres -> NAME != NULL)
+	{
+	  if(gethtitem(resname,scanres -> NAME) != EMPTYHT)
+	    {
+	      do
+		{
+		  nb++ ;
+		  sprintf(name,"%s_%d",scanres -> NAME,nb) ;
+		  ptr = namealloc(name) ;
+		}
+
+	      while(gethtitem(resname,ptr) != EMPTYHT) ;
+
+	      addhtitem(resname,ptr,1) ;
+	      tooutput(df,"R%s ",name) ;    
+	    }
+	  else
+	    {
+	      tooutput(df,"R%s ",scanres -> NAME) ;
+	      addhtitem(resname,scanres -> NAME,1) ;
+	    }
+	}
+      else
+	{
+	  do
+	    {
+	      nb++ ;
+	      sprintf(name,"%d",nb) ;
+	      ptr = namealloc(name) ;
+	    }
+
+	  while(gethtitem(resname,ptr) != EMPTYHT) ;
+
+	  tooutput(df,"R%s ",name) ;
+	  addhtitem(resname,ptr,1) ;
+	}
+
+      sortconnecteur(df,scanres -> RCON1,1) ;
+      sortconnecteur(df,scanres -> RCON2,1) ;
+
+      tooutput(df,"%g ",(float)scanres -> RESI) ;
+
+      tooutput(df,"\n") ;
+    }
+
+  delht(resname) ;
+}
+
+/****************************************************************************************************/
+
+void sort_loself(lofig_list *ptfig,FILE *df)
+{
+  loself_list	*scanself   = NULL ;
+  int		nb         = 0    ;
+  ht            *selfname   = NULL ;
+  char          name[1024]        ;
+  char          *ptr       = NULL ;
+
+  for(scanself = ptfig -> LOSELF,nb = 1 ; scanself != NULL; scanself = scanself -> NEXT,nb++) ;
+
+  selfname = addht(nb) ;
+
+  nb = 0 ;
+
+  for(scanself = ptfig -> LOSELF ; scanself != NULL ; scanself = scanself -> NEXT)
+    {
+      if(scanself -> NAME != NULL)
+	{
+	  if(gethtitem(selfname,scanself -> NAME) != EMPTYHT)
+	    {
+	      do
+		{
+		  nb++ ;
+		  sprintf(name,"%s_%d",scanself -> NAME,nb) ;
+		  ptr = namealloc(name) ;
+		}
+
+	      while(gethtitem(selfname,ptr) != EMPTYHT) ;
+
+	      addhtitem(selfname,ptr,1) ;
+	      tooutput(df,"L%s ",name) ;    
+	    }
+	  else
+	    {
+	      tooutput(df,"L%s ",scanself -> NAME) ;
+	      addhtitem(selfname,scanself -> NAME,1) ;
+	    }
+	}
+      else
+	{
+	  do
+	    {
+	      nb++ ;
+	      sprintf(name,"%d",nb) ;
+	      ptr = namealloc(name) ;
+	    }
+
+	  while(gethtitem(selfname,ptr) != EMPTYHT) ;
+
+	  tooutput(df,"L%s ",name) ;
+	  addhtitem(selfname,ptr,1) ;
+	}
+
+      sortconnecteur(df,scanself -> SCON1,1) ;
+      sortconnecteur(df,scanself -> SCON2,1) ;
+
+      tooutput(df,"%g ",(float)scanself -> SELF) ;
+
+      tooutput(df,"\n") ;
+    }
+
+  delht(selfname) ;
+}
