@@ -4,7 +4,7 @@
  * Universite Pierre et Marie Curie
  * 
  * Home page          : http://www-asim.lip6.fr/alliance/
- * E-mail support     : mailto:alliance-support@asim.lip6.fr
+ * E-mail             : mailto:alliance-users@asim.lip6.fr
  * 
  * This library is free software; you  can redistribute it and/or modify it
  * under the terms  of the GNU Library General Public  License as published
@@ -40,6 +40,9 @@
 
 /*
  * $Log: parse_vti_p.c,v $
+ * Revision 1.3  2002/09/30 16:21:00  czo
+ * support/users
+ *
  * Revision 1.2  2002/03/14 12:34:30  fred
  * Using new headers
  *
@@ -74,7 +77,7 @@
  * rcs version number consistency
  *
  */
-#ident "$Id: parse_vti_p.c,v 1.2 2002/03/14 12:34:30 fred Exp $"
+#ident "$Id: parse_vti_p.c,v 1.3 2002/09/30 16:21:00 czo Exp $"
 
 #include <string.h>
 #include <ctype.h>
