@@ -54,6 +54,20 @@ PPlacement::~PPlacement()
     {
 	delete *nit;
     }
+
+    for (PRows::iterator rit = _rows.begin();
+	    rit != _rows.end();
+	    rit++)
+    {
+	delete *rit;
+    }
+
+    for (PDetSubRows::iterator srit = _detSubRows.begin();
+	    srit != _detSubRows.end();
+	    srit++)
+    {
+	delete *srit;
+    }
 }
 
 void
@@ -142,7 +156,7 @@ PPlacement::Init(lofig* fig, int NbRows)
     }
     
     for (locon* con = fig->LOCON; con; con = con->NEXT)
-      ploconmap[con->NAME] = con;
+	ploconmap[con->NAME] = con;
     
     // traitement de l'emplacement des connecteurs
     // creation des PCon si fichier ioc
@@ -217,7 +231,7 @@ PPlacement::Init(lofig* fig, int NbRows)
 	    pnetmap[sig->INDEX] = net;
 	}
 	else {
-       cerr << " o Special Net detected : " << getsigname(sig) << endl;
+	    cerr << " o Special Net detected : " << getsigname(sig) << endl;
 	}
     }
 
@@ -391,10 +405,11 @@ PPlacement::Init(lofig* fig, int NbRows)
     // Insertion of instances on rows
     vector<PToPlaceIns*>::iterator iptfirst = ClassedInss.begin();
     PRows::iterator rfirst = _rows.begin();
-    PRow::PSubRows::iterator subrfirst = rfirst->GetSubRows().begin();
+    PRow::PSubRows::iterator subrfirst = (*rfirst)->GetSubRows().begin();
     
     PIns* InsInserting = *iptfirst;
-    while(1) {
+    while(1) 
+    {
         int NbOfBins;
         int BinNumber;
             
@@ -405,10 +420,10 @@ PPlacement::Init(lofig* fig, int NbRows)
             // end of insertion
         }
 
-	if (subrfirst == rfirst->GetSubRows().end()
+	if (subrfirst == (*rfirst)->GetSubRows().end()
 		&& (++rfirst != _rows.end()))
 	{
-	    subrfirst = rfirst->GetSubRows().begin();
+	    subrfirst = (*rfirst)->GetSubRows().begin();
 	}
 	
         if (rfirst == _rows.end()) 
@@ -417,21 +432,22 @@ PPlacement::Init(lofig* fig, int NbRows)
             {
                 InsInserting = *iptfirst;
                 rfirst = _rows.begin();
-		subrfirst = rfirst->GetSubRows().begin();
+		subrfirst = (*rfirst)->GetSubRows().begin();
             }
             else
             {
                 // insertion of instances with respect of Bins margin
                 // did not succed, inserting what's left.
                 rfirst = _rows.begin();
-		subrfirst = rfirst->GetSubRows().begin();
-                NbOfBins = subrfirst->GetNBins();
+		subrfirst = (*rfirst)->GetSubRows().begin();
+                NbOfBins = (*subrfirst)->GetNBins();
                 BinNumber = 0;
-                while (iptfirst != ClassedInss.end()) {
+                while (iptfirst != ClassedInss.end()) 
+		{
                     if ((*iptfirst)->GetWidth() <=
-                            subrfirst->GetWidth() - subrfirst->GetSize())
+                           (*subrfirst)->GetWidth() - (*subrfirst)->GetSize())
                     {
-                        subrfirst->ForceIns(**(iptfirst++), BinNumber++);
+                        (*subrfirst)->ForceIns(**(iptfirst++), BinNumber++);
                     }
                     else
                         BinNumber++;
@@ -439,15 +455,15 @@ PPlacement::Init(lofig* fig, int NbRows)
                     {
                         subrfirst++;
                         BinNumber = 0;
-			if (subrfirst != rfirst->GetSubRows().end())
-			    NbOfBins = subrfirst->GetNBins();
+			if (subrfirst != (*rfirst)->GetSubRows().end())
+			    NbOfBins = (*subrfirst)->GetNBins();
                     }
 
-		    if (subrfirst == rfirst->GetSubRows().end()
+		    if (subrfirst == (*rfirst)->GetSubRows().end()
 			    && (++rfirst != _rows.end()))
 		    {
-			subrfirst = rfirst->GetSubRows().begin();
-			NbOfBins = subrfirst->GetNBins();
+			subrfirst = (*rfirst)->GetSubRows().begin();
+			NbOfBins = (*subrfirst)->GetNBins();
 		    }
 		    
                     if (rfirst == _rows.end())
@@ -462,19 +478,21 @@ PPlacement::Init(lofig* fig, int NbRows)
                             exit(1);
                         }
                         rfirst = _rows.begin();
-			subrfirst = rfirst->GetSubRows().begin();
+			subrfirst = (*rfirst)->GetSubRows().begin();
+			NbOfBins = (*subrfirst)->GetNBins();
+			BinNumber = 0;
                         InsInserting = *iptfirst;
                     }
                 }
             }
         }
-        NbOfBins = subrfirst->GetNBins();
+        NbOfBins = (*subrfirst)->GetNBins();
         BinNumber = 0;
         while ((iptfirst != ClassedInss.end())
                 && (BinNumber < NbOfBins)
-                && ((*iptfirst)->GetWidth() <= subrfirst->GetCapa() - subrfirst->GetSize()))
+                && ((*iptfirst)->GetWidth() <= (*subrfirst)->GetCapa() - (*subrfirst)->GetSize()))
         {
-            if (subrfirst->InsertIns(**iptfirst, BinNumber++))
+            if ((*subrfirst)->InsertIns(**iptfirst, BinNumber++))
 	    {
                 iptfirst++;
 	    }
@@ -700,43 +718,48 @@ PPlacement::SetPosIocFile(PConMap& pconmap)
 void
 PPlacement::ParseIocFile(PLoconMap& ploconmap)
 {
-  PPos position;
-  
-  _PtList = iocparse(_iocFileName);
-  
-  char orientation;
-  
-  for(con_list* tmpcon = _PtList ; tmpcon ; tmpcon = tmpcon->NEXT)
-  {
-    if (strcmp(tmpcon->NAME,"SPACE") != 0)
+    PPos position;
+
+    _PtList = iocparse(_iocFileName);
+
+    char orientation;
+
+    for(con_list* tmpcon = _PtList ; tmpcon ; tmpcon = tmpcon->NEXT)
     {
-	if (ploconmap.find(tmpcon->NAME) == ploconmap.end())
+	if (strcmp(tmpcon->NAME,"SPACE") != 0)
 	{
-	    cerr << " o Error in ioc file ...." << endl
-		 << "   The connector " << tmpcon->NAME
-		 << " doesn't exist in your figure ...."
-		 << endl;
-	    exit(1);
+	    if (ploconmap.find(tmpcon->NAME) == ploconmap.end())
+	    {
+		cerr << " o Error in ioc file ...." << endl
+		    << "   The connector " << tmpcon->NAME
+		    << " doesn't exist in your figure ...."
+		    << endl;
+		exit(1);
+	    }
+	    switch (tmpcon->ORIENT)
+	    {
+		case 'T':
+		    orientation = NORTH;
+		    break;
+		case 'B':
+		    orientation = SOUTH;
+		    break;
+		case 'L':
+		    orientation = WEST;
+		    break;
+		case 'R':
+		    orientation = EAST;
+		    break;
+		default:
+		    cerr << "Unknown Orientation for connector: "
+			<< tmpcon->NAME << endl;
+		    exit(1);
+	    }
+	    position.SetX(0);
+	    position.SetY(0);
+	    InsertCon(ploconmap[tmpcon->NAME], position, orientation);
 	}
-      switch (tmpcon->ORIENT)
-      {
-	case 'T' : orientation = NORTH;
-		   break;
-	case 'B' : orientation = SOUTH;
-		   break;
-	case 'L' : orientation = WEST;
-		   break;
-	case 'R' : orientation = EAST;
-		   break;
-	default: cerr << "Unknown Orientation for connector: "
-		 << tmpcon->NAME << endl;
-		 exit(1);
-      }
-	position.SetX(0);
-	position.SetY(0);
-	InsertCon(ploconmap[tmpcon->NAME], position, orientation);
     }
-  }
 }
 
 // ======================================================================
@@ -839,9 +862,9 @@ PPlacement::PlotInstances(ofstream& out) const
 {
   
   out << "#rows" << endl;
-  for (PRows::const_iterator RowIt=_rows.begin(); RowIt!=_rows.end(); RowIt++)
+  for (PRows::const_iterator rit=_rows.begin(); rit!=_rows.end(); rit++)
   {
-      RowIt->Plot(out);
+      (*rit)->Plot(out);
   }
   out << "EOF" << endl;
   out << "#to place instances" << endl;
@@ -885,9 +908,9 @@ PPlacement::PlotAll(char* output) const
     PlotInstances(out);
   
     out << "#nets" << endl;
-    for (PONets::const_iterator NetIt=_nets.begin(); NetIt!=_nets.end(); NetIt++)
+    for (PONets::const_iterator nit=_nets.begin(); nit!=_nets.end(); nit++)
     {
-	(*NetIt)->Plot(out);
+	(*nit)->Plot(out);
     }
     out << "EOF" << endl << "pause -1 'press any key'" << endl;
 }
@@ -924,33 +947,33 @@ PPlacement::PlotFinal(char* output) const
     out << "EOF" << endl;
 
     out << "#subrows" << endl;
-    for (PDetSubRows::const_iterator SRowIt = _detSubRows.begin() ;
-	  SRowIt != _detSubRows.end() ;
-	  SRowIt++)
+    for (PDetSubRows::const_iterator srit = _detSubRows.begin() ;
+	  srit != _detSubRows.end() ;
+	  srit++)
     {
-	SRowIt->Plot(out);
+	(*srit)->Plot(out);
     }
     out << "EOF" << endl;
 
     out << "#instances" << endl;
 
-    for (PDetSubRows::const_iterator SRowIt = _detSubRows.begin() ;
-	    SRowIt != _detSubRows.end() ;
-	    SRowIt++)
+    for (PDetSubRows::const_iterator srit = _detSubRows.begin() ;
+	    srit != _detSubRows.end() ;
+	    srit++)
     {
-	for (PDetSubRow::PDetInsVector::const_iterator InsIt = SRowIt->GetConstInssVector().begin() ;
-		InsIt != SRowIt->GetConstInssVector().end() ;
-		InsIt++)
+	for (PDetSubRow::PDetInsVector::const_iterator iit = (*srit)->GetConstInssVector().begin() ;
+		iit != (*srit)->GetConstInssVector().end() ;
+		iit++)
 	{
-	    InsIt->Plot(out);
+	    (*iit)->Plot(out);
 	}
     }
     out << "EOF" << endl;
     out << "#nets" << endl;
 
-    for (PONets::const_iterator NetIt=_nets.begin(); NetIt!=_nets.end(); NetIt++)
+    for (PONets::const_iterator nit=_nets.begin(); nit!=_nets.end(); nit++)
     {
-	(*NetIt)->Plot(out);
+	(*nit)->Plot(out);
     }
     out << "EOF" << endl << "pause -1 'press any key'" << endl;
 }
@@ -996,24 +1019,24 @@ PPlacement::PlotOnlyBins(char* output) const
 
     if (_totalMoves != 0)
     {
-	for (PRows::const_iterator RowIt=_rows.begin(); RowIt!=_rows.end(); RowIt++)
+	for (PRows::const_iterator rit=_rows.begin(); rit!=_rows.end(); rit++)
 	{
-	    RowIt->PlotLabel(out, _totalMoves);
+	    (*rit)->PlotLabel(out, _totalMoves);
 	}
     }
 
     out << "plot [:][:] '-' w l 1, '-' w l 2" << endl << "#bins" << endl;
-    for (PRows::const_iterator RowIt=_rows.begin(); RowIt!=_rows.end(); RowIt++)
+    for (PRows::const_iterator rit=_rows.begin(); rit!=_rows.end(); rit++)
     {
-	RowIt->Plot(out);
+	(*rit)->Plot(out);
     }
 
     out << "EOF" << endl;
     out << "#preplaced instances" << endl;
-    for (PFixedInss::const_iterator insit = _fixedInss.begin();
-	    insit != _fixedInss.end(); insit++)
+    for (PFixedInss::const_iterator iit = _fixedInss.begin();
+	    iit != _fixedInss.end(); iit++)
     {
-	(*insit)->Plot(out);
+	(*iit)->Plot(out);
     }
     out << "EOF" << endl;
     out << "pause -1 'press any key'" << endl;
@@ -1026,8 +1049,9 @@ PPlacement::PlotStat()
 {
     ofstream out("stat.gpl");
 
-  out << "set title 'all stats'\n#set terminal postscript color solid\n"
-    << "set output 'stat.ps'" << endl
+  out << "set title 'all stats'" << endl
+    << "#set terminal postscript color solid" << endl
+    << "#set output 'stat.ps'" << endl
     << "plot 'alldata.dat' using 1:2 title 'temperature' with lines,"
     << "'alldata.dat' using 1:3 title 'cost' with lines,"
     << "'alldata.dat' using 1:4 title 'rowcost' with lines,"
@@ -1048,7 +1072,8 @@ PPlacement::GenerateConsPlacement()
     //creation d'un placement aleatoire des connecteurs.
     unsigned faces[4];
     double aspectRatio = GetWidth() / GetHeight();
-    unsigned nbConsNorthSouth = (unsigned)((_cons.size() / 2) * aspectRatio);
+    double repartition = aspectRatio + 1.0;
+    unsigned nbConsNorthSouth = (unsigned)( aspectRatio * _cons.size() / repartition);
     unsigned nbConsEastWest = _cons.size() - nbConsNorthSouth;
     
     //faces north est sud ouest
@@ -1069,55 +1094,67 @@ PPlacement::GenerateConsPlacement()
     int spaceLeft = 0;
     
     //placement au nord.
-    interval = (maxx - minx) / faces[0];
-    spaceLeft = (maxx - minx) % faces[0];
-    pos = minx + interval / 2;
-    while(faces[0]--)
+    if (faces[0])
     {
-	if (spaceLeft-- > 0)
-	    pos += 1;
-	(*cit)->SetOrient(NORTH);
-	(*cit++)->SetPos(PPos(pos , maxy));
-	pos += interval;
+	interval = (maxx - minx) / faces[0];
+	spaceLeft = (maxx - minx) % faces[0];
+	pos = minx + interval / 2;
+	while(faces[0]--)
+	{
+	    if (spaceLeft-- > 0)
+		pos += 1;
+	    (*cit)->SetOrient(NORTH);
+	    (*cit++)->SetPos(PPos(pos , maxy));
+	    pos += interval;
+	}
     }
     
     //placement a l'est.
-    interval = (maxy - miny) / faces[1];
-    spaceLeft = (maxx - minx) % faces[1];
-    pos = miny + interval / 2;
-    while(faces[1]--)
+    if (faces[1])
     {
-	if (spaceLeft-- > 0)
-	    pos += 1;
-	(*cit)->SetOrient(EAST);
-	(*cit++)->SetPos(PPos(maxx , pos));
-	pos += interval;
+	interval = (maxy - miny) / faces[1];
+	spaceLeft = (maxy - miny) % faces[1];
+	pos = miny + interval / 2;
+	while(faces[1]--)
+	{
+	    if (spaceLeft-- > 0)
+		pos += 1;
+	    (*cit)->SetOrient(EAST);
+	    (*cit++)->SetPos(PPos(maxx , pos));
+	    pos += interval;
+	}
     }
     
     //placement au sud.
-    interval = (maxx - minx) / faces[2];
-    spaceLeft = (maxx - minx) % faces[2];
-    pos = minx + interval / 2;
-    while(faces[2]--)
+    if (faces[2])
     {
-	if (spaceLeft-- > 0)
-	    pos += 1;
-	(*cit)->SetOrient(SOUTH);
-	(*cit++)->SetPos(PPos(pos , miny));
-	pos += interval;
+	interval = (maxx - minx) / faces[2];
+	spaceLeft = (maxx - minx) % faces[2];
+	pos = minx + interval / 2;
+	while(faces[2]--)
+	{
+	    if (spaceLeft-- > 0)
+		pos += 1;
+	    (*cit)->SetOrient(SOUTH);
+	    (*cit++)->SetPos(PPos(pos , miny));
+	    pos += interval;
+	}
     }
     
     //placement a l'ouest.
-    interval = (maxy - miny) / faces[3];
-    spaceLeft = (maxx - minx) % faces[3];
-    pos = miny + interval / 2;
-    while(faces[3]--)
+    if (faces[3])
     {
-	if (spaceLeft-- > 0)
-	    pos += 1;
-	(*cit)->SetOrient(WEST);
-	(*cit++)->SetPos(PPos(minx , pos));
-	pos += interval;
+	interval = (maxy - miny) / faces[3];
+	spaceLeft = (maxy - miny) % faces[3];
+	pos = miny + interval / 2;
+	while(faces[3]--)
+	{
+	    if (spaceLeft-- > 0)
+		pos += 1;
+	    (*cit)->SetOrient(WEST);
+	    (*cit++)->SetPos(PPos(minx , pos));
+	    pos += interval;
+	}
     }
 }
 
@@ -1150,29 +1187,35 @@ PPlacement::GenerateRingConsPlacement()
     int spaceLeft = 0;
     
     //placement au nord.
-    interval = (maxx - minx) / faces[0];
-    spaceLeft = (maxx - minx) % faces[0];
-    pos = minx + interval / 2;
-    while(faces[0]--)
+    if (faces[0])
     {
-	if (spaceLeft-- > 0)
-	    pos += 1;
-	(*cit)->SetOrient(NORTH);
-	(*cit++)->SetPos(PPos(pos , maxy));
-	pos += interval;
+	interval = (maxx - minx) / faces[0];
+	spaceLeft = (maxx - minx) % faces[0];
+	pos = minx + interval / 2;
+	while(faces[0]--)
+	{
+	    if (spaceLeft-- > 0)
+		pos += 1;
+	    (*cit)->SetOrient(NORTH);
+	    (*cit++)->SetPos(PPos(pos , maxy));
+	    pos += interval;
+	}
     }
     
     //placement au sud.
-    interval = (maxx - minx) / faces[1];
-    spaceLeft = (maxx - minx) % faces[1];
-    pos = minx + interval / 2;
-    while(faces[1]--)
+    if (faces[1])
     {
-	if (spaceLeft-- > 0)
-	    pos += 1;
-	(*cit)->SetOrient(SOUTH);
-	(*cit++)->SetPos(PPos(pos , miny));
-	pos += interval;
+	interval = (maxx - minx) / faces[1];
+	spaceLeft = (maxx - minx) % faces[1];
+	pos = minx + interval / 2;
+	while(faces[1]--)
+	{
+	    if (spaceLeft-- > 0)
+		pos += 1;
+	    (*cit)->SetOrient(SOUTH);
+	    (*cit++)->SetPos(PPos(pos , miny));
+	    pos += interval;
+	}
     }
 }
     
@@ -1214,27 +1257,27 @@ PPlacement::InitPlace(int NbRows)
     _rowZeroOrientation = RowOrientation;
     for (int i = 0; i < NRows; i++)
     {
-	_rows.push_back(PRow(1));
+	_rows.push_back(new PRow(1));
         double XMin = 0.0;
-	_rows.back().Init(Y, XMin, *this, RowOrientation);
+	_rows.back()->Init(Y, XMin, *this, RowOrientation);
 	_rowsYMax[Y + ROWHEIGHT] = rowidx;
 	_rowsYMinInv[Y] = rowidx;
 	++rowidx;
-	PSubRow& subrow = _rows.back()._subRows[0];
-	subrow.Init(&(_rows.back()), Y, XMin, rowwidth, _margin, 
+	PSubRow& subrow = *(_rows.back()->_subRows[0]);
+	subrow.Init(_rows.back(), Y, XMin, rowwidth, _margin, 
 		_binsMaxWidth, _binsMinWidth);
-	_rows.back()._subRowsXMax[rowwidth + XMin] = 0;
-	_rows.back()._subRowsXMaxInv[rowwidth + XMin] = 0;
+	_rows.back()->_subRowsXMax[rowwidth + XMin] = 0;
+	_rows.back()->_subRowsXMaxInv[rowwidth + XMin] = 0;
         Y += ROWHEIGHT;
 	RowOrientation = !RowOrientation;
     }
 
     // Computing Placement BBox
     double MaxX = 0.0, MaxY = 0.0, RowMaxX, RowMaxY;
-    for (PRows::iterator rfirst = _rows.begin(); rfirst != _rows.end(); rfirst++)
+    for (PRows::iterator rit = _rows.begin(); rit != _rows.end(); rit++)
     {
-        RowMaxX = rfirst->GetMaxX();
-        RowMaxY = rfirst->GetMaxY();
+        RowMaxX = (*rit)->GetMaxX();
+        RowMaxY = (*rit)->GetMaxY();
         if (MaxX < RowMaxX)
             MaxX = RowMaxX;
         if (MaxY < RowMaxY)
@@ -1395,11 +1438,11 @@ PPlacement::InitPlaceWithPrePlace()
 	  int numsubrows = CheckCreateRow(tabpreplace, yit, Width);
 	  if (numsubrows > 0)
 	  {
-	    _rows.push_back(PRow(*this, (double)(yit * ROWHEIGHT), Width, numsubrows, orientation));
+	    _rows.push_back(new PRow(*this, (double)(yit * ROWHEIGHT), Width, numsubrows, orientation));
 	    _rowsYMax[(yit + 1) * ROWHEIGHT] = numrows;
 	    _rowsYMinInv[yit * ROWHEIGHT] = numrows;
 	    ++numrows;
-	    CreateSubRows(&_rows.back(), tabpreplace, yit, numsubrows, Width);
+	    CreateSubRows(_rows.back(), tabpreplace, yit, numsubrows, Width);
 	  }
 	  orientation = !orientation;
 	}
@@ -1440,7 +1483,7 @@ PPlacement::CreateSubRows(PRow* row, PrePlaceTab& tabpreplace,
 
     if ( (xmax - xmin) >= _binsMinWidth)
     {
-	row->_subRows[subrowscreated].Init(row, (double)(coordy * ROWHEIGHT), (double)xmin,(double)xmax,
+	row->_subRows[subrowscreated]->Init(row, (double)(coordy * ROWHEIGHT), (double)xmin,(double)xmax,
 		(double)_margin, _binsMaxWidth, _binsMinWidth);
 	row->_subRowsXMax[(double)xmax] = subrowscreated;
 	++subrowscreated;
@@ -1510,5 +1553,5 @@ PPlacement::GetRow(const PRow* row, const double dist)
     PRowsYMax::iterator rsup = _rowsYMinInv.upper_bound(bornesup);
 
     unsigned randidx = rinf->second + (unsigned)((double)(rsup->second - rinf->second + 1) * (rand() / (RAND_MAX+1.0)));
-    return _rows[randidx];
+    return *_rows[randidx];
 }
