@@ -1,6 +1,6 @@
 
 /*
- *  $Id: DEF_actions.c,v 1.1.1.1 2002/04/25 16:16:20 jpc Exp $
+ *  $Id: DEF_actions.c,v 1.3 2003/06/26 17:00:39 jpc Exp $
  *
  *  /----------------------------------------------------------------\
  *  |                                                                |
@@ -8,7 +8,7 @@
  *  |  S i l i c o n   E n s e m b l e / A l l i a n c e             |
  *  |                                                                |
  *  |  Author    :                      Jean-Paul CHAPUT             |
- *  |  E-mail    :         alliance-support@asim.lip6.fr             |
+ *  |  E-mail    :         alliance-users@asim.lip6.fr             |
  *  | ============================================================== |
  *  |  C Module  :         "./DEF_actions.c"                         |
  *  | ************************************************************** |
@@ -560,9 +560,10 @@ extern void	 def_pin_options()
         break;
     } /* End of "switch (LV_orient)". */
 
-    if (!fakeCon) {
-      LV_ptLoseg->tLoseg[pElem->VALUE] = addloseg (
-           LV_ptLoseg->tLoseg[pElem->VALUE], LOSEG_SEGCON, (void*)pPhSeg);
+    if (!fakeCon || (LV_defFlags & F_DEF_KEEP_IOS)) {
+      if (!fakeCon)
+        LV_ptLoseg->tLoseg[pElem->VALUE] = addloseg (
+          LV_ptLoseg->tLoseg[pElem->VALUE], LOSEG_SEGCON, (void*)pPhSeg);
 
 
         /* Add the old-style terminal. */
