@@ -1,5 +1,5 @@
 /*
- *  $Id: DEF_drive.c,v 1.1.1.1 2002/04/25 16:16:20 jpc Exp $
+ *  $Id: DEF_drive.c,v 1.10 2003/06/26 17:00:39 jpc Exp $
  *
  *  /----------------------------------------------------------------\
  *  |                                                                |
@@ -7,7 +7,7 @@
  *  |  S i l i c o n   E n s e m b l e / A l l i a n c e             |
  *  |                                                                |
  *  |  Author    :                      Jean-Paul CHAPUT             |
- *  |  E-mail    :         alliance-support@asim.lip6.fr             |
+ *  |  E-mail    :         alliance-users@asim.lip6.fr             |
  *  | ============================================================== |
  *  |  C Module  :         "./DEF_drive.c"                           |
  *  | ************************************************************** |
@@ -458,11 +458,11 @@ static char *USEtoa(acUSE)
 {
   switch(acUSE) {
     case C_USE_NONE:   return((char*)NULL);
-    case C_USE_SIGNAL: return("signal");
-    case C_USE_ANALOG: return("analog");
-    case C_USE_POWER:  return("power");
-    case C_USE_GROUND: return("ground");
-    case C_USE_CLOCK:  return("clock");
+    case C_USE_SIGNAL: return("SIGNAL");
+    case C_USE_ANALOG: return("ANALOG");
+    case C_USE_POWER:  return("POWER");
+    case C_USE_GROUND: return("GROUND");
+    case C_USE_CLOCK:  return("CLOCK");
   }
 
   return((char*)NULL);
@@ -1144,12 +1144,14 @@ static void  fprintPIN(apLocon, apPhcon, asState)
      */
 
     fprintf(DEF_FILE, " + DIRECTION INPUT + USE GROUND");
+  } else if (isck(apLocon->NAME)) {
+    fprintf(DEF_FILE, " + DIRECTION INPUT + USE CLOCK");  
   } else 
     fprintf(DEF_FILE, " + DIRECTION %s",
                        DIRtoa(MBK2DEF_locondir(apLocon)));
   
-  if (    (LV_Flags & F_FIXED_PINS)
-      &&  (strncmp(apLocon->NAME, "vddv", 4))
+  if (    /* (LV_Flags & F_FIXED_PINS) */
+      /*&&*/  (strncmp(apLocon->NAME, "vddv", 4))
       &&  (strncmp(apLocon->NAME, "vssv", 4))
       &&  !isvdd (apLocon->NAME)
       &&  !isvss (apLocon->NAME)) {
@@ -1535,7 +1537,7 @@ static void  fprintNETS()
   for(pLoSig = LV_lofig->LOSIG, loSigNB = 0L;
       pLoSig != (losig_list*)NULL; pLoSig = pLoSig->NEXT) {
     sSig = getsigname(pLoSig);
-    if (isvdd(sSig) || isvss(sSig)) continue;
+    if (isvdd(sSig) || isvss(sSig) || isck(sSig)) continue;
 
     loSigNB += 1;
   }
@@ -1549,7 +1551,8 @@ static void  fprintNETS()
     sSig = getsigname(pLoSig);
     if (     isvdd(sSig) 
         ||   isvss(sSig)
-        || !strcmp(sSig, "cki")) continue;
+        ||   !strcmp(sSig, "cki")
+        ||   isck(sSig)) continue;
 
     fprintNET(pLoSig, C_USE_NONE);
   }
@@ -1579,7 +1582,8 @@ static void  fprintSPECIALNETS()
     sSig = getsigname(pLoSig);
     if (    !isvdd(sSig)
         &&  !isvss(sSig)
-        &&  strcmp(sSig, "cki")) continue;
+        &&  strcmp(sSig, "cki")
+        &&  !isck(sSig)) continue;
 
     loSigNB += 1;
   }
@@ -1597,6 +1601,7 @@ static void  fprintSPECIALNETS()
     if (  isvdd(sSig)       ) Use = C_USE_POWER;
     if (  isvss(sSig)       ) Use = C_USE_GROUND;
     if (!strcmp(sSig, "cki")) Use = C_USE_CLOCK;
+    if (  isck(sSig)        ) Use = C_USE_CLOCK;
     if (Use == C_USE_NONE) continue;
 
     fprintNET(pLoSig, Use);
@@ -1614,8 +1619,13 @@ static void  fprintSPECIALNETS()
 
 static void  fprintDEF()
 {
-  fprintf (DEF_FILE, "DESIGN %s ;\n\n\n"                   , LV_name);
-  fprintf (DEF_FILE, "    TECHNOLOGY %s ;\n\n"             , "cmos_12");
+  fprintf (DEF_FILE, "VERSION             5.2 ;\n");
+  fprintf (DEF_FILE, "NAMESCASESENSITIVE  ON ;\n");
+  fprintf (DEF_FILE, "BUSBITCHARS         \"()\" ;\n");
+  fprintf (DEF_FILE, "DIVIDERCHAR         \".\" ;\n\n");
+
+  fprintf (DEF_FILE, "DESIGN %s ;\n\n", LV_name);
+  fprintf (DEF_FILE, "    TECHNOLOGY %s ;\n\n"             , "cmos");
   fprintf (DEF_FILE, "    UNITS DISTANCE MICRONS %ld ;\n", DEF_UNITS_MICRONS);
 
   if (LV_phfig) {
