@@ -1,5 +1,5 @@
 /*
- *  $Id: util_Defs.h,v 1.2 2002/05/11 17:03:38 xtof Exp $
+ *  $Id: util_Defs.h,v 1.4 2002/09/30 16:21:18 czo Exp $
  *
  *  /----------------------------------------------------------------\
  *  |                                                                |
@@ -7,7 +7,7 @@
  *  |  S i l i c o n   E n s e m b l e / A l l i a n c e             |
  *  |                                                                |
  *  |  Author    :                      Jean-Paul CHAPUT             |
- *  |  E-mail    :         alliance-support@asim.lip6.fr             |
+ *  |  E-mail    :         alliance-users@asim.lip6.fr             |
  *  | ============================================================== |
  *  |  C Header  :         "./util_Defs.h"                           |
  *  | ************************************************************** |
@@ -122,7 +122,7 @@
 
   /* Interruptions handling functions. */
   extern void  trapInit    __FP((void));
-  extern void  sendGSignal __FP((int aSig));
+  /*extern void  sendGSignal __FP((int aSig));*/
   extern void  setBinName  __FP((char *asName));
 
   /* Errors printing functions. */
