@@ -1,6 +1,6 @@
 
 /*
- *  $Id: util_MBK.c,v 1.1.1.1 2002/04/25 16:16:20 jpc Exp $
+ *  $Id: util_MBK.c,v 1.3 2003/09/16 10:14:38 jpc Exp $
  *
  *  /----------------------------------------------------------------\
  *  |                                                                |
@@ -8,7 +8,7 @@
  *  |  S i l i c o n   E n s e m b l e / A l l i a n c e             |
  *  |                                                                |
  *  |  Author    :                      Jean-Paul CHAPUT             |
- *  |  E-mail    :         alliance-support@asim.lip6.fr             |
+ *  |  E-mail    :         alliance-users@asim.lip6.fr             |
  *  | ============================================================== |
  *  |  C Module  :         "./util_MBK.c"                            |
  *  | ************************************************************** |
@@ -1450,8 +1450,11 @@ extern void  addfeed (apLofig, apPhfig)
 
 
   /* Find VDD & VSS signals. */
-  for (sigVDD = apLofig->LOSIG;
-       !isvdd (getsigname (sigVDD)); sigVDD = sigVDD->NEXT);
+  sigVDD = apLofig->LOSIG;
+  while (sigVDD != NULL) {
+    if (isvdd (getsigname (sigVDD))) break;
+    sigVDD = sigVDD->NEXT;
+  }
 
   if (!sigVDD) {
     errMBK  (NULL);
@@ -1459,8 +1462,11 @@ extern void  addfeed (apLofig, apPhfig)
     EXIT (1);
   }
 
-  for (sigVSS = apLofig->LOSIG;
-       !isvss (getsigname (sigVSS)); sigVSS = sigVSS->NEXT);
+  sigVSS = apLofig->LOSIG;
+  while (sigVSS != NULL) {
+    if (isvdd (getsigname (sigVSS))) break;
+    sigVSS = sigVSS->NEXT;
+  }
 
   if (!sigVSS) {
     errMBK  (NULL);
