@@ -4,7 +4,7 @@
 | (C) Laboratoire LIP6 - Dpartement ASIM Universite P&M Curie|
 |                                                             |
 | Home page      : http://www-asim.lip6.fr/alliance/          |
-| E-mail support : mailto:alliance-support@asim.lip6.fr       |
+| E-mail         : mailto:alliance-users@asim.lip6.fr       |
 |                                                             |
 | This progam is  free software; you can redistribute it      |
 | and/or modify it under the  terms of the GNU General Public |
@@ -428,7 +428,7 @@ static vexexpr *VasyAllianceTreatVexArith( VexExpr )
     sprintf( Buffer, "rtlgen_%ld", VasyNumberDef );
     VexAtomGen = createvexatomvec( Buffer,  MaxWidth - 1, 1 );
 
-    if ( VasyFlagLax ) VasyAllianceAddKeepSignal( VexAtomGen );
+    if ( VasyFlagLax || VasyFlagBoom ) VasyAllianceAddKeepSignal( VexAtomGen );
 
     RtlDeclGen = addrtldecl( VasyRtlFigure, dupvexexpr( VexAtomGen ), RTL_DECLAR_SIGNAL );
     RtlDeclGen->BASE = VEX_TYPE_BIT_VECTOR;
@@ -443,7 +443,7 @@ static vexexpr *VasyAllianceTreatVexArith( VexExpr )
     sprintf( Buffer, "rtlprop_%ld", VasyNumberDef );
     VexAtomProp = createvexatomvec( Buffer,  MaxWidth - 1, 1 );
 
-    if ( VasyFlagLax ) VasyAllianceAddKeepSignal( VexAtomProp );
+    if ( VasyFlagLax || VasyFlagBoom ) VasyAllianceAddKeepSignal( VexAtomProp );
 
     RtlDeclProp = addrtldecl( VasyRtlFigure, dupvexexpr( VexAtomProp ), RTL_DECLAR_SIGNAL );
     RtlDeclProp->BASE = VEX_TYPE_BIT_VECTOR;
@@ -521,7 +521,7 @@ static vexexpr *VasyAllianceTreatVexArith( VexExpr )
 
         VexAtom3 = createvexatomvec( GetVexAtomValue( VexAtomCarry ), Index , Index );
 
-        if ( VasyFlagLax ) VasyAllianceAddKeepSignal( VexAtom3 );
+        if ( VasyFlagLax || VasyFlagBoom ) VasyAllianceAddKeepSignal( VexAtom3 );
 
         RtlAsgCarry = addrtlasg( VasyRtlFigure, VexAtom3, RTL_ASG_COMBINATORIAL );
         RtlAsgCarry->VEX_DATA = VexCarry;
@@ -543,7 +543,7 @@ static vexexpr *VasyAllianceTreatVexArith( VexExpr )
       VexCarry = createvexbinexpr( VEX_OR, MaxWidth - 1, VexAnd1 , VexAnd2 );
       VexCarry = createvexbinexpr( VEX_OR, MaxWidth - 1, VexCarry, VexAnd3 );
 
-      if ( VasyFlagLax ) VasyAllianceAddKeepSignal( VexAtom4 );
+      if ( VasyFlagLax || VasyFlagBoom ) VasyAllianceAddKeepSignal( VexAtom4 );
 
       RtlAsgCarry = addrtlasg( VasyRtlFigure, VexAtom4, RTL_ASG_COMBINATORIAL );
       RtlAsgCarry->VEX_DATA = simpvexexpr( VexCarry );
@@ -912,7 +912,7 @@ static vexexpr *VasyAllianceTreatVexRelational( VexExpr )
     sprintf( Buffer, "rtlgen_%ld", VasyNumberDef );
     VexAtomGen = createvexatomvec( Buffer,  MaxWidth - 1, 1 );
 
-    if ( VasyFlagLax ) VasyAllianceAddKeepSignal( VexAtomGen );
+    if ( VasyFlagLax || VasyFlagBoom ) VasyAllianceAddKeepSignal( VexAtomGen );
 
     RtlDeclGen = addrtldecl( VasyRtlFigure, dupvexexpr( VexAtomGen ), RTL_DECLAR_SIGNAL );
     RtlDeclGen->BASE = VEX_TYPE_BIT_VECTOR;
@@ -927,7 +927,7 @@ static vexexpr *VasyAllianceTreatVexRelational( VexExpr )
     sprintf( Buffer, "rtlprop_%ld", VasyNumberDef );
     VexAtomProp = createvexatomvec( Buffer,  MaxWidth - 1, 1 );
 
-    if ( VasyFlagLax ) VasyAllianceAddKeepSignal( VexAtomProp );
+    if ( VasyFlagLax || VasyFlagBoom ) VasyAllianceAddKeepSignal( VexAtomProp );
 
     RtlDeclProp = addrtldecl( VasyRtlFigure, dupvexexpr( VexAtomProp ), RTL_DECLAR_SIGNAL );
     RtlDeclProp->BASE = VEX_TYPE_BIT_VECTOR;
@@ -1018,7 +1018,7 @@ static vexexpr *VasyAllianceTreatVexRelational( VexExpr )
 
       VexAtom3 = createvexatomvec( GetVexAtomValue( VexAtomCarry ), Index , Index );
 
-      if ( VasyFlagLax ) VasyAllianceAddKeepSignal( VexAtom3 );
+      if ( VasyFlagLax || VasyFlagBoom ) VasyAllianceAddKeepSignal( VexAtom3 );
 
       RtlAsgCarry = addrtlasg( VasyRtlFigure, VexAtom3, RTL_ASG_COMBINATORIAL );
       RtlAsgCarry->VEX_DATA = VexCarry;
@@ -1040,7 +1040,7 @@ static vexexpr *VasyAllianceTreatVexRelational( VexExpr )
     VexCarry = createvexbinexpr( VEX_OR, MaxWidth - 1, VexAnd1 , VexAnd2 );
     VexCarry = createvexbinexpr( VEX_OR, MaxWidth - 1, VexCarry, VexAnd3 );
 
-    if ( VasyFlagLax ) VasyAllianceAddKeepSignal( VexAtom4 );
+    if ( VasyFlagLax || VasyFlagBoom ) VasyAllianceAddKeepSignal( VexAtom4 );
 
     RtlAsgCarry = addrtlasg( VasyRtlFigure, VexAtom4, RTL_ASG_COMBINATORIAL );
     RtlAsgCarry->VEX_DATA = simpvexexpr( VexCarry );
@@ -1118,7 +1118,7 @@ static vexexpr *VasyAllianceTreatVexEqual( VexExpr )
   VexNXor = createvexbinexpr( VEX_NXOR, MaxWidth, 
                               dupvexexpr( Operand1 ), dupvexexpr( Operand2 ) );
 
-  if ( VasyFlagLax ) VasyAllianceAddKeepSignal( VexAtomNXor );
+  if ( VasyFlagLax || VasyFlagBoom  ) VasyAllianceAddKeepSignal( VexAtomNXor );
 
   RtlAsgNXor = addrtlasg( VasyRtlFigure, VexAtomNXor, RTL_ASG_COMBINATORIAL );
   RtlAsgNXor->VEX_DATA = VexNXor;
@@ -1348,7 +1348,7 @@ static void VasyAllianceTreatMap( RtlInst )
     {
       sprintf( Buffer, "rtl_map_%ld", VasyNumberDef++ );
     
-      if ( isvextypevector( Type ) )
+      if ( isvextypevector( RtlPort->BASE ) )
       {
         VexAtom = createvexatomvec( Buffer, VexActual->WIDTH - 1, 0 );
       }
@@ -1588,7 +1588,19 @@ static void VasyDriveAllianceTreatDeclar( RtlFigure )
       AtomName   = GetVexAtomValue( VexDeclar );
 
       if ( VexInit != (vexexpr *)0 ) AtomValue = GetVexAtomValue( VexInit   );
-      else                           AtomValue = (char *)0;
+      else 
+      {
+#if 1  /** Francois Donnet: 16/01/2003: do not initialize by default
+       *** because someone else could do it in an upper hierachy.
+       *** It's better not to correct description and to let user
+       *** with it's own error than to build some...
+       **/
+         if ( ( RtlDeclar->DIR == RTL_DIR_INOUT           ) ) continue;
+#endif
+         
+         /*default init for outputs*/
+         AtomValue = (char *)0;
+      }
   
       for ( ScanPos = 0; ScanPos < VexDeclar->WIDTH; ScanPos++ )
       {
